import{c as n,a as d}from"./BLoZk-4Q.js";import"./DnbEMVOy.js";import{f as i}from"./CkWh75VR.js";import{I as l,s as c}from"./Bmr4jBBJ.js";import{l as m,s as f}from"./BIAtSU2q.js";function g(o,t){const e=m(t,["children","$$slots","$$events","$$legacy"]);/**
 * @license lucide-svelte v0.469.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const s=[["path",{d:"M15 2H6a2 2 0 0 0-2 2v16a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V7Z"}],["path",{d:"M14 2v4a2 2 0 0 0 2 2h4"}],["path",{d:"M10 9H8"}],["path",{d:"M16 13H8"}],["path",{d:"M16 17H8"}]];l(o,f({name:"file-text"},()=>e,{get iconNode(){return s},children:(r,h)=>{var a=n(),p=i(a);c(p,t,"default",{}),d(r,a)},$$slots:{default:!0}}))}export{g as F};
