import{c as w,a as i,f as x,s as H}from"./BLoZk-4Q.js";import"./DnbEMVOy.js";import{f as q,P as J,Q as O,T as _,R as M,U as V,K as a,t as Z,V as m}from"./CkWh75VR.js";import{I as F,s as K,e as X,i as Y,a as I,c as ee,t as te}from"./Bmr4jBBJ.js";import{l as L,s as S,a as ae,i as A,b as se}from"./BIAtSU2q.js";import{c as re}from"./KAGS2ztk.js";import{M as oe,F as ne}from"./D4o-w7gg.js";import{C as ie}from"./D6PP_X6J.js";import{C as le}from"./DzYtD4Df.js";import{C as ce}from"./CxSD3vMp.js";import{C as de}from"./SdiQyPyy.js";function we(l,s){const c=L(s,["children","$$slots","$$events","$$legacy"]);/**
 * @license lucide-svelte v0.469.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const d=[["path",{d:"M3.85 8.62a4 4 0 0 1 4.78-4.77 4 4 0 0 1 6.74 0 4 4 0 0 1 4.78 4.78 4 4 0 0 1 0 6.74 4 4 0 0 1-4.77 4.78 4 4 0 0 1-6.75 0 4 4 0 0 1-4.78-4.77 4 4 0 0 1 0-6.76Z"}],["path",{d:"m9 12 2 2 4-4"}]];F(l,S({name:"badge-check"},()=>c,{get iconNode(){return d},children:(p,o)=>{var r=w(),n=q(r);K(n,s,"default",{}),i(p,r)},$$slots:{default:!0}}))}function xe(l,s){const c=L(s,["children","$$slots","$$events","$$legacy"]);/**
 * @license lucide-svelte v0.469.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const d=[["path",{d:"M2.97 12.92A2 2 0 0 0 2 14.63v3.24a2 2 0 0 0 .97 1.71l3 1.8a2 2 0 0 0 2.06 0L12 19v-5.5l-5-3-4.03 2.42Z"}],["path",{d:"m7 16.5-4.74-2.85"}],["path",{d:"m7 16.5 5-3"}],["path",{d:"M7 16.5v5.17"}],["path",{d:"M12 13.5V19l3.97 2.38a2 2 0 0 0 2.06 0l3-1.8a2 2 0 0 0 .97-1.71v-3.24a2 2 0 0 0-.97-1.71L17 10.5l-5 3Z"}],["path",{d:"m17 16.5-5-3"}],["path",{d:"m17 16.5 4.74-2.85"}],["path",{d:"M17 16.5v5.17"}],["path",{d:"M7.97 4.42A2 2 0 0 0 7 6.13v4.37l5 3 5-3V6.13a2 2 0 0 0-.97-1.71l-3-1.8a2 2 0 0 0-2.06 0l-3 1.8Z"}],["path",{d:"M12 8 7.26 5.15"}],["path",{d:"m12 8 4.74-2.85"}],["path",{d:"M12 13.5V8"}]];F(l,S({name:"boxes"},()=>c,{get iconNode(){return d},children:(p,o)=>{var r=w(),n=q(r);K(n,s,"default",{}),i(p,r)},$$slots:{default:!0}}))}var pe=x('<div class="phase-line svelte-11chv7q"></div>'),ve=x('<div class="phase-cell svelte-11chv7q"><!> <div><!></div> <span> </span></div>'),me=x('<div class="phase-bar svelte-11chv7q"></div>');function qe(l,s){J(s,!0);const c=()=>se(te,"$t",d),[d,p]=ae(),o=[{key:"clarify",icon:oe},{key:"plan",icon:ie},{key:"implement",icon:le},{key:"tests",icon:ne},{key:"done",icon:ce}];let r=m(()=>["clarify","plan","implement","tests"].every(e=>s.phases[e]==="complete"));function n(e){return e==="done"?a(r)?"complete":"not_started":s.phases[e]||"not_started"}function W(e){return e==="complete"?"ok":["in_progress","draft","awaiting_review"].includes(e)?"wip":""}function P(e){return e==="complete"?"var(--gn-bright)":["in_progress","draft","awaiting_review"].includes(e)?"var(--yl)":"var(--bg2)"}var u=me();X(u,21,()=>o,Y,(e,g,$)=>{const z=m(()=>n(a(g).key)),h=m(()=>W(a(z))),Q=m(()=>$<o.length-1?n(o[$+1].key):"not_started"),R=m(()=>a(g).icon);var k=ve(),B=M(k);{var T=t=>{var v=pe();Z((b,C)=>ee(v,`background: linear-gradient(to right, ${b??""}, ${C??""})`),[()=>P(a(z)),()=>P(a(Q))]),i(t,v)};A(B,t=>{$<o.length-1&&t(T)})}var f=V(B,2),U=M(f);{var j=t=>{de(t,{size:13,strokeWidth:2.5})},D=t=>{var v=w(),b=q(v);re(b,()=>a(R),(C,G)=>{G(C,{size:13,strokeWidth:1.5})}),i(t,v)};A(U,t=>{a(h)==="ok"?t(j):t(D,!1)})}_(f);var y=V(f,2);let N;var E=M(y,!0);_(y),_(k),Z(t=>{I(f,1,`dot ${a(h)??""}`,"svelte-11chv7q"),N=I(y,1,"phase-lbl svelte-11chv7q",null,N,{"lbl-ok":a(h)==="ok","lbl-wip":a(h)==="wip"}),H(E,t)},[()=>c()("phase."+a(g).key)]),i(e,k)}),_(u),i(l,u),O(),p()}export{we as B,qe as P,xe as a};
