import{c as l,a as p}from"./BLoZk-4Q.js";import"./DnbEMVOy.js";import{f as i}from"./CkWh75VR.js";import{I as d,s as m}from"./Bmr4jBBJ.js";import{l as c,s as f}from"./BIAtSU2q.js";function y(r,t){const o=c(t,["children","$$slots","$$events","$$legacy"]);/**
 * @license lucide-svelte v0.469.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const e=[["path",{d:"m21.73 18-8-14a2 2 0 0 0-3.48 0l-8 14A2 2 0 0 0 4 21h16a2 2 0 0 0 1.73-3"}],["path",{d:"M12 9v4"}],["path",{d:"M12 17h.01"}]];d(r,f({name:"triangle-alert"},()=>o,{get iconNode(){return e},children:(s,$)=>{var a=l(),n=i(a);m(n,t,"default",{}),p(s,a)},$$slots:{default:!0}}))}export{y as T};
