.guidance-input.svelte-2jwyo5{width:100%;padding:.5rem .75rem;background:var(--bg2);border:.0625rem solid var(--bd);border-radius:var(--r);color:var(--tx);font-size:.875rem;font-family:inherit;resize:vertical;min-height:3.75rem;margin-bottom:.5rem}.guidance-input.svelte-2jwyo5:focus{outline:none;border-color:var(--ac);box-shadow:0 0 0 .0625rem var(--ac2)}.plan-task.svelte-af73pf{border:.0625rem solid var(--bd);border-radius:var(--r);padding:.625rem .875rem;margin-bottom:.5rem;background:var(--bg2)}.plan-task.svelte-af73pf h4:where(.svelte-af73pf){font-size:.875rem;color:var(--tx-bright);margin:0}.pf-head.svelte-af73pf{display:flex;justify-content:space-between}.pf-desc.svelte-af73pf{font-size:.8125rem;color:var(--dm);margin:.125rem 0 0}.pf-deps.svelte-af73pf{font-size:.75rem;color:var(--dm2);margin-top:.125rem}.prio.svelte-af73pf{font-size:.6875rem;color:var(--or);font-family:var(--font-ui)}.section-title.svelte-7j1cah{font-size:1rem;font-weight:600;color:var(--tx-bright);margin-bottom:.5rem}.proposal-details.svelte-7j1cah{margin:.625rem 0}.details-summary.svelte-7j1cah{cursor:pointer;color:var(--ac);font-size:.8125rem;font-weight:600;margin-bottom:.375rem}
