import{t as m,h as l,a as _,c as E,d as M,g as h,C as y,i as A,j as N,H as g,s as w,k as C,N as T,l as b,m as d}from"./CkWh75VR.js";import{b as c}from"./BLoZk-4Q.js";function S(u,p,r=!1,s=!1,H=!1){var i=u,t="";m(()=>{var n=E;if(t===(t=p()??"")){l&&_();return}if(n.nodes!==null&&(M(n.nodes.start,n.nodes.end),n.nodes=null),t!==""){if(l){h.data;for(var e=_(),o=e;e!==null&&(e.nodeType!==y||e.data!=="");)o=e,e=A(e);if(e===null)throw N(),g;c(h,o),i=w(e);return}var v=r?T:s?b:void 0,f=C(r?"svg":s?"math":"template",v);f.innerHTML=t;var a=r||s?f:f.content;if(c(d(a),a.lastChild),r||s)for(;d(a);)i.before(d(a));else i.before(a)}})}export{S as h};
