import{a as h,f as g,s as e}from"../chunks/BLoZk-4Q.js";import{i as l}from"../chunks/DnbEMVOy.js";import{P as v,f as d,t as _,Q as x,R as o,T as p,U as $}from"../chunks/CkWh75VR.js";import{s as k,p as m}from"../chunks/Dz-gMz0b.js";const b={get error(){return m.error},get status(){return m.status}};k.updated.check;const f=b;var E=g("<h1> </h1> <p> </p>",1);function U(i,n){v(n,!1),l();var r=E(),t=d(r),c=o(t,!0);p(t);var s=$(t,2),u=o(s,!0);p(s),_(()=>{var a;e(c,f.status),e(u,(a=f.error)==null?void 0:a.message)}),h(i,r),x()}export{U as component};
