.task-item.svelte-a8gvc2{cursor:pointer;transition:box-shadow .2s;display:block;text-decoration:none;color:inherit}.task-item.svelte-a8gvc2:hover{box-shadow:0 .5rem 2rem #0000001a;text-decoration:none}.task-head.svelte-a8gvc2{display:flex;justify-content:space-between;align-items:center}h3.svelte-a8gvc2{margin:0;display:flex;align-items:center;gap:.5rem}.status-icon.svelte-a8gvc2{display:flex;align-items:center;justify-content:center;flex-shrink:0}.status-icon.complete.svelte-a8gvc2{color:var(--gn-bright)}.status-icon.wip.svelte-a8gvc2{color:var(--tx-bright)}.milestone-badge.svelte-a8gvc2{font-size:.6875rem;padding:.125rem .5rem;border-radius:.25rem;background:color-mix(in srgb,var(--ac) 12%,transparent);border:none;color:var(--ac);font-family:var(--font-ui);letter-spacing:.019rem;white-space:nowrap}.progress-bar.svelte-a8gvc2{height:.1875rem;background:var(--bd);border-radius:.125rem;margin-top:.25rem;overflow:hidden}.progress-fill.svelte-a8gvc2{height:100%;background:var(--ac);border-radius:.125rem;transition:width .3s}.progress-label.svelte-a8gvc2{font-size:.75rem;color:var(--dm);margin-top:.25rem;font-family:var(--font-ui)}.progress-label.progress-complete.svelte-a8gvc2{color:var(--ac);font-weight:600}.milestone-tabs-layout.svelte-giyzvd{display:flex;gap:1.5rem;margin-top:1.5rem}.milestone-tabs-nav.svelte-giyzvd{position:sticky;top:0;width:14rem;flex-shrink:0;align-self:flex-start;display:flex;flex-direction:column;gap:.2rem;padding:0;padding-top:1rem}.tab-item.svelte-giyzvd{display:flex;align-items:center;width:100%;padding:.75rem;border:none;border-radius:var(--r);background:none;color:var(--tx-bright);font-size:1rem;font-family:inherit;text-align:left;cursor:pointer;white-space:nowrap;overflow:hidden;text-overflow:ellipsis;transition:background .1s}.tab-item.svelte-giyzvd:hover{background:var(--bg2)}.tab-item.active.svelte-giyzvd{background:var(--bg2);color:var(--tx-bright)}.milestone-tabs-content.svelte-giyzvd{flex:1;min-width:0;display:flex;flex-direction:column;gap:.75rem}
