.md-content.svelte-1ibqn6c{line-height:1.65;color:var(--tx);margin-bottom:2rem}.md-content.svelte-1ibqn6c h1{font-size:1.0625rem;margin:.875rem 0 .375rem;padding-bottom:.25rem;color:var(--tx-bright)}.md-content.svelte-1ibqn6c h2{font-size:1.5rem;margin:1.3rem 0 .7rem;color:var(--or)}.md-content.svelte-1ibqn6c h3{font-size:1.2rem;margin:1.2rem 0 .7rem;color:var(--tx-bright)}.md-content.svelte-1ibqn6c p{margin:1rem 0}.md-content.svelte-1ibqn6c ul,.md-content.svelte-1ibqn6c ol{margin:.25rem 0 .25rem 1.25rem}.md-content.svelte-1ibqn6c li{margin:.125rem 0}.md-content.svelte-1ibqn6c pre{position:relative;background:var(--bg2);border-radius:var(--r);padding:1.2rem 1.5rem;overflow-x:auto;font-size:.8125rem;margin:.375rem 0;font-family:var(--font-ui)}.md-content.svelte-1ibqn6c code{background:none;padding:0;border-radius:0;font-size:.8125rem}.md-content.svelte-1ibqn6c .copy-btn{position:absolute;top:.5rem;right:.5rem;display:inline-flex;align-items:center;justify-content:center;width:1.75rem;height:1.75rem;background:transparent;border:.0625rem solid var(--bd);border-radius:var(--r);color:var(--dm);cursor:pointer;opacity:0;transition:opacity .15s,color .15s,border-color .15s}.md-content.svelte-1ibqn6c pre:hover .copy-btn{opacity:1}.md-content.svelte-1ibqn6c .copy-btn:hover{color:var(--tx-bright);border-color:var(--tx2)}.md-content.svelte-1ibqn6c .copy-btn.copied{color:var(--gn-bright);border-color:var(--gn-bright);opacity:1}.md-content.svelte-1ibqn6c blockquote{border-left:.1875rem solid var(--ac2);padding-left:.625rem;color:var(--dm);margin:.375rem 0}.md-content.svelte-1ibqn6c table{border-collapse:separate;border-spacing:0;width:100%;margin:.375rem 0;background:var(--bg2);border-radius:var(--r);overflow:hidden;border:.0625rem solid var(--bd)}.md-content.svelte-1ibqn6c thead{background:var(--sf)}.md-content.svelte-1ibqn6c th,.md-content.svelte-1ibqn6c td{border-bottom:.0625rem solid var(--bd);border-right:.0625rem solid var(--bd);padding:.25rem .5rem;text-align:left;font-size:.8125rem;word-wrap:break-word;overflow-wrap:break-word}.md-content.svelte-1ibqn6c th:last-child,.md-content.svelte-1ibqn6c td:last-child{border-right:none}.md-content.svelte-1ibqn6c tr:last-child td{border-bottom:none}.md-content.svelte-1ibqn6c th{background:var(--sf);color:var(--tx-bright);font-weight:600}.md-content.svelte-1ibqn6c hr{border:none;border-top:.0625rem solid var(--bd);margin:.625rem 0}.md-content.svelte-1ibqn6c strong{color:var(--tx-bright)}
