.toolbar.svelte-1w1dn0{display:flex;align-items:center;padding:.375rem 0;background:var(--sf);border-bottom:.0625rem solid var(--bd);flex-shrink:0;overflow:hidden}.toolbar-spacer.svelte-1w1dn0{flex-shrink:0}.toolbar-gap.svelte-1w1dn0{width:.1875rem;flex-shrink:0}.toolbar-content.svelte-1w1dn0{flex:1;min-width:0;display:flex;align-items:center;justify-content:space-between;gap:.5rem;padding:0 .75rem}.toolbar-groups.svelte-1w1dn0{display:flex;align-items:center;gap:.125rem;flex-wrap:wrap}.sep.svelte-1w1dn0{width:.0625rem;height:1.25rem;background:var(--bd2);margin:0 .25rem;flex-shrink:0}.tb-btn.svelte-1w1dn0{display:inline-flex;align-items:center;justify-content:center;width:1.875rem;height:1.75rem;border:none;border-radius:var(--r2);background:transparent;color:var(--tx);cursor:pointer;font-family:var(--font-ui);font-size:.75rem;transition:background .1s,color .1s}.tb-btn.svelte-1w1dn0:hover{background:var(--sf2);color:var(--tx-bright)}.tb-btn.svelte-1w1dn0:active{background:var(--bg3)}.tb-label.svelte-1w1dn0{font-weight:600;font-size:.6875rem}.toolbar-actions.svelte-1w1dn0{display:flex;align-items:center;gap:.375rem;flex-shrink:0}.preview-pane.svelte-1g94l1e{display:flex;flex-direction:column;min-width:0;height:100%;overflow:hidden}.pane-header.svelte-1g94l1e{font-size:.6875rem;text-transform:uppercase;letter-spacing:.0312rem;color:var(--dm);font-weight:600;padding:.375rem .75rem;border-bottom:.0625rem solid var(--bd);flex-shrink:0}.pane-body.svelte-1g94l1e{flex:1;overflow-y:auto;padding:.75rem 1rem}.empty-hint.svelte-1g94l1e{color:var(--dm2);font-style:italic;font-size:.8125rem}.editor-pane.svelte-oojubp{display:flex;flex-direction:column;min-width:0;height:100%;overflow:hidden}.pane-header.svelte-oojubp{font-size:.6875rem;text-transform:uppercase;letter-spacing:.0312rem;color:var(--dm);font-weight:600;padding:.375rem .75rem;border-bottom:.0625rem solid var(--bd);flex-shrink:0}.editor-textarea.svelte-oojubp{flex:1;width:100%;resize:none;border:none;outline:none;background:var(--bg2);color:var(--tx);font-family:var(--font-ui);font-size:.8125rem;line-height:1.6;padding:.75rem 1rem;-moz-tab-size:4;tab-size:4;overflow-y:auto}.editor-textarea.svelte-oojubp::placeholder{color:var(--dm2)}.divider.svelte-1w3avtj{width:.1875rem;flex-shrink:0;display:flex;align-items:center;justify-content:center;cursor:col-resize;background:var(--bd);transition:background .1s;position:relative;z-index:2}.divider.svelte-1w3avtj:hover,.divider.dragging.svelte-1w3avtj{background:var(--bd2)}.handle.svelte-1w3avtj{position:absolute;width:.5rem;height:2.5rem;border-radius:var(--r2);background:var(--dm2);transition:background .1s}.divider.svelte-1w3avtj:hover .handle:where(.svelte-1w3avtj),.divider.dragging.svelte-1w3avtj .handle:where(.svelte-1w3avtj){background:var(--ac)}.md-editor-overlay.svelte-h6uur0{position:fixed;top:0;right:0;bottom:0;left:0;z-index:1100;background:var(--bg);display:flex;flex-direction:column;max-width:none!important;margin:0!important;width:100vw!important}.md-editor-modal.svelte-h6uur0{display:flex;flex-direction:column;width:100%;height:100%;overflow:hidden}.split-container.svelte-h6uur0{flex:1;display:flex;min-height:0;overflow:hidden}.split-left.svelte-h6uur0,.split-right.svelte-h6uur0{min-width:0;overflow:hidden}
