.file-tabs-layout.svelte-1kr7grw{display:flex;gap:1.5rem;margin-top:1.5rem}.file-tabs-nav.svelte-1kr7grw{position:sticky;top:0;width:14rem;flex-shrink:0;align-self:flex-start;display:flex;flex-direction:column;gap:.2rem;padding:0;padding-top:1rem}.tab-item.svelte-1kr7grw{display:flex;align-items:center;width:100%;padding:.75rem;border:none;border-radius:var(--r);background:none;color:var(--tx-bright);font-size:1rem;font-family:inherit;text-align:left;cursor:pointer;white-space:nowrap;overflow:hidden;text-overflow:ellipsis;transition:background .1s}.tab-item.svelte-1kr7grw:hover{background:var(--bg2)}.tab-item.active.svelte-1kr7grw{background:var(--bg2);color:var(--tx-bright)}.file-tabs-content.svelte-1kr7grw{flex:1;min-width:0}
