import{c as i,a as n}from"./BLoZk-4Q.js";import"./DnbEMVOy.js";import{f as p}from"./CkWh75VR.js";import{I as l,s as m}from"./Bmr4jBBJ.js";import{l as d,s as f}from"./BIAtSU2q.js";function v(s,r){const t=d(r,["children","$$slots","$$events","$$legacy"]);/**
 * @license lucide-svelte v0.469.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const e=[["circle",{cx:"12",cy:"12",r:"10"}],["path",{d:"m15 9-6 6"}],["path",{d:"m9 9 6 6"}]];l(s,f({name:"circle-x"},()=>t,{get iconNode(){return e},children:(a,$)=>{var o=i(),c=p(o);m(c,r,"default",{}),n(a,o)},$$slots:{default:!0}}))}export{v as C};
