.phase-bar.svelte-11chv7q{display:flex;align-items:flex-start;margin:2rem 0}.phase-cell.svelte-11chv7q{flex:1;display:flex;flex-direction:column;align-items:center;position:relative}.phase-line.svelte-11chv7q{position:absolute;top:.6875rem;left:50%;right:-50%;height:.125rem;background:var(--bg2);z-index:0;transition:background .2s}.phase-cell.svelte-11chv7q:last-child .phase-line:where(.svelte-11chv7q){display:none}.dot.svelte-11chv7q{width:1.5rem;height:1.5rem;border-radius:50%;border:.125rem solid var(--bg2);flex-shrink:0;position:relative;z-index:1;display:flex;align-items:center;justify-content:center;color:var(--tx);background:var(--bg2);transition:all .2s}.dot.ok.svelte-11chv7q{background:var(--gn-bright);border-color:var(--gn-bright);color:#fff}.dot.wip.svelte-11chv7q{background:var(--yl);border-color:var(--yl);color:var(--bg2)}.phase-lbl.svelte-11chv7q{font-size:.7rem;color:var(--tx);margin-top:.375rem;white-space:nowrap;text-align:center;font-family:var(--font-ui);transition:color .2s}.phase-lbl.lbl-ok.svelte-11chv7q{color:var(--gn-bright)}.phase-lbl.lbl-wip.svelte-11chv7q{color:var(--yl)}
